==> apache-iceberg-0.14.1.tar.gz: apache-iceberg-0.14.1/api/src/main/java/org/apache/iceberg/SplittableScanTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iceberg;

/**
 * A scan task that can be split into smaller scan tasks.
 *
 * @param <ThisT> the child Java API class
 */
public interface SplittableScanTask<ThisT> extends ScanTask {
  /**
   * Attempts to split this scan task into several smaller scan tasks, each close to {@code splitSize} size.
   * <p>
   * Note the target split size is just guidance and the actual split size may be either smaller or larger.
   * File formats like Parquet may leverage the row group offset information while splitting tasks.
   *
   * @param targetSplitSize the target size of each new scan task in bytes
   * @return an Iterable of smaller tasks
   */
  Iterable<ThisT> split(long targetSplitSize);
}

==> apache-iceberg-1.10.1.tar.gz: apache-iceberg-1.10.1/api/src/main/java/org/apache/iceberg/SplittableScanTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg;

/**
 * A scan task that can be split into smaller scan tasks.
 *
 * @param <ThisT> the child Java API class
 */
public interface SplittableScanTask<ThisT> extends ScanTask {
  /**
   * Attempts to split this scan task into several smaller scan tasks, each close to {@code
   * splitSize} size.
   *
   * <p>Note the target split size is just guidance and the actual split size may be either smaller
   * or larger. File formats like Parquet may leverage the row group offset information while
   * splitting tasks.
   *
   * @param targetSplitSize the target size of each new scan task in bytes
   * @return an Iterable of smaller tasks
   */
  Iterable<ThisT> split(long targetSplitSize);
}
